Task: Personality_Captions
===========================
Description: 200k images from the YFCC100m dataset (https://multimediacommons.wordpress.com/yfcc100m-core-dataset/), with captions conditioned on one of 215 personalities. See https://arxiv.org/abs/1810.10665 for more information.

Tags: #Personality_Captions, #All, #Visual

Notes: If you have already downloaded the images, please specify with the `--yfcc-path` flag, as the image download script takes a very long time to run

